==> isis-fish-4.0.0.1-sources.jar: fr/ifremer/isisfish/util/Args.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: Args.java 3393 2011-06-14 17:43:37Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2006 - 2011 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.util;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation pour specifier le nom des arguments car il est impossible
 * de les avoir par introspection.
 *
 * Created: 4 juil. 2006 12:40:46
 *
 * @author poussin
 * @version $Revision: 3393 $
 *
 * Last update: $Date: 2011-06-14 19:43:37 +0200 (mar., 14 juin 2011) $
 * by : $Author: chatellier $
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD})
public @interface Args {
    String[] value();
}

==> isis-fish-4.1.0.2-sources.jar: fr/ifremer/isisfish/util/Args.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: Args.java 3671 2012-04-03 13:31:36Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2006 - 2012 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.util;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation pour specifier le nom des arguments car il est impossible
 * de les avoir par introspection.
 * Même via paranamer c'est impossible car sur les interfaces les noms
 * ne sont pas présent dans le bytecode.
 *
 * Created: 4 juil. 2006 12:40:46
 *
 * @author poussin
 * @version $Revision: 3671 $
 *
 * Last update: $Date: 2012-04-03 15:31:36 +0200 (Tue, 03 Apr 2012) $
 * by : $Author: echatellier $
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD})
public @interface Args {
    String[] value();
}
